=== modified file 'bzrlib/_btree_serializer_pyx.pyx'
--- bzrlib/_btree_serializer_pyx.pyx	2009-10-08 04:10:43 +0000
+++ bzrlib/_btree_serializer_pyx.pyx	2009-10-08 05:12:01 +0000
@@ -38,8 +38,6 @@
     Py_ssize_t PyString_Size(object p)
     Py_ssize_t PyString_GET_SIZE_ptr "PyString_GET_SIZE" (PyObject *)
     char * PyString_AS_STRING_ptr "PyString_AS_STRING" (PyObject *)
-    char * PyString_AS_STRING(object)
-    Py_ssize_t PyString_GET_SIZE(object)
     int PyString_AsStringAndSize_ptr(PyObject *, char **buf, Py_ssize_t *len)
     void PyString_InternInPlace(PyObject **)
     int PyTuple_CheckExact(object t)
@@ -57,12 +55,6 @@
     # void *memrchr(void *s, int c, size_t n)
     int strncmp(char *s1, char *s2, size_t n)
 
-# It seems we need to import the definitions so that the pyrex compiler has
-# local names to access them.
-from _static_tuple_c cimport StaticTuple, \
-    import_static_tuple_c, StaticTuple_New, \
-    StaticTuple_Intern, StaticTuple_SET_ITEM, StaticTuple_CheckExact
-
 
 # TODO: Find some way to import this from _dirstate_helpers
 cdef void* _my_memrchr(void *s, int c, size_t n):
@@ -79,7 +71,6 @@
         pos = pos - 1
     return NULL
 
-
 # TODO: Import this from _dirstate_helpers when it is merged
 cdef object safe_string_from_size(char *s, Py_ssize_t size):
     if size < 0:
@@ -103,12 +94,6 @@
     Py_DECREF_ptr(py_str)
     return result
 
-from bzrlib import _static_tuple_c
-cdef object _ST
-_ST = _static_tuple_c.StaticTuple
-# This sets up the StaticTuple C_API functionality
-import_static_tuple_c()
-
 
 cdef class BTreeLeafParser:
     """Parse the leaf nodes of a BTree index.
@@ -148,7 +133,6 @@
         self._cur_str = NULL
         self._end_str = NULL
         self._header_found = 0
-        # keys are tuples
 
     cdef extract_key(self, char * last):
         """Extract a key.
@@ -158,9 +142,8 @@
         """
         cdef char *temp_ptr
         cdef int loop_counter
-        cdef StaticTuple key
-        
-        key = StaticTuple_New(self.key_length)
+        # keys are tuples
+        key = PyTuple_New(self.key_length)
         for loop_counter from 0 <= loop_counter < self.key_length:
             # grab a key segment
             temp_ptr = <char*>memchr(self._start, c'\0', last - self._start)
@@ -175,19 +158,15 @@
                                                    last - self._start)))
                     raise AssertionError(failure_string)
             # capture the key string
-            if (self.key_length == 1 
-                and (temp_ptr - self._start) == 45
-                and strncmp(self._start, 'sha1:', 5) == 0):
-                key_element = safe_string_from_size(self._start,
-                                                    temp_ptr - self._start)
-            else:
-                key_element = safe_interned_string_from_size(self._start,
+            # TODO: Consider using PyIntern_FromString, the only caveat is that
+            # it assumes a NULL-terminated string, so we have to check if
+            # temp_ptr[0] == c'\0' or some other char.
+            key_element = safe_interned_string_from_size(self._start,
                                                          temp_ptr - self._start)
             # advance our pointer
             self._start = temp_ptr + 1
             Py_INCREF(key_element)
-            StaticTuple_SET_ITEM(key, loop_counter, key_element)
-        key = StaticTuple_Intern(key)
+            PyTuple_SET_ITEM(key, loop_counter, key_element)
         return key
 
     cdef int process_line(self) except -1:
@@ -197,7 +176,6 @@
         cdef char *ref_ptr
         cdef char *next_start
         cdef int loop_counter
-        cdef Py_ssize_t str_len
 
         self._start = self._cur_str
         # Find the next newline
@@ -233,25 +211,12 @@
             # Invalid line
             raise AssertionError("Failed to find the value area")
         else:
-            # Because of how conversions were done, we ended up with *lots* of
-            # values that are identical. These are all of the 0-length nodes
-            # that are referred to by the TREE_ROOT (and likely some other
-            # directory nodes.) For example, bzr has 25k references to
-            # something like '12607215 328306 0 0', which ends up consuming 1MB
-            # of memory, just for those strings.
-            str_len = last - temp_ptr - 1
-            if (str_len > 4
-                and strncmp(" 0 0", last - 4, 4) == 0):
-                # This drops peak mem for bzr.dev from 87.4MB => 86.2MB
-                # For Launchpad 236MB => 232MB
-                value = safe_interned_string_from_size(temp_ptr + 1, str_len)
-            else:
-                value = safe_string_from_size(temp_ptr + 1, str_len)
+            # capture the value string
+            value = safe_string_from_size(temp_ptr + 1, last - temp_ptr - 1)
             # shrink the references end point
             last = temp_ptr
-
         if self.ref_list_length:
-            ref_lists = StaticTuple_New(self.ref_list_length)
+            ref_lists = []
             loop_counter = 0
             while loop_counter < self.ref_list_length:
                 ref_list = []
@@ -283,20 +248,18 @@
                     if temp_ptr == NULL:
                         # key runs to the end
                         temp_ptr = ref_ptr
-                                        
                     PyList_Append(ref_list, self.extract_key(temp_ptr))
-                ref_list = StaticTuple_Intern(StaticTuple(*ref_list))
-                Py_INCREF(ref_list)
-                StaticTuple_SET_ITEM(ref_lists, loop_counter - 1, ref_list)
+                PyList_Append(ref_lists, tuple(ref_list))
                 # prepare for the next reference list
                 self._start = next_start
-            node_value = StaticTuple(value, ref_lists)
+            ref_lists = tuple(ref_lists)
+            node_value = (value, ref_lists)
         else:
             if last != self._start:
                 # unexpected reference data present
                 raise AssertionError("unexpected reference data present")
-            node_value = StaticTuple(value, StaticTuple())
-        PyList_Append(self.keys, StaticTuple(key, node_value))
+            node_value = (value, ())
+        PyList_Append(self.keys, (key, node_value))
         return 0
 
     def parse(self):
@@ -331,6 +294,7 @@
     cdef Py_ssize_t flat_len
     cdef Py_ssize_t key_len
     cdef Py_ssize_t node_len
+    cdef PyObject * val
     cdef char * value
     cdef Py_ssize_t value_len
     cdef char * out
@@ -339,12 +303,13 @@
     cdef int first_ref_list
     cdef int first_reference
     cdef int i
+    cdef PyObject *ref_bit
     cdef Py_ssize_t ref_bit_len
 
-    if not PyTuple_CheckExact(node) and not StaticTuple_CheckExact(node):
-        raise TypeError('We expected a tuple() or StaticTuple() for node not: %s'
+    if not PyTuple_CheckExact(node):
+        raise TypeError('We expected a tuple() for node not: %s'
             % type(node))
-    node_len = len(node)
+    node_len = PyTuple_GET_SIZE(node)
     have_reference_lists = reference_lists
     if have_reference_lists:
         if node_len != 4:
@@ -354,7 +319,7 @@
         raise ValueError('Without ref_lists, we need at least 3 entries not: %s'
             % len(node))
     # I don't expect that we can do faster than string.join()
-    string_key = '\0'.join(node[1])# <object>PyTuple_GET_ITEM_ptr_object(node, 1))
+    string_key = '\0'.join(<object>PyTuple_GET_ITEM_ptr_object(node, 1))
 
     # TODO: instead of using string joins, precompute the final string length,
     #       and then malloc a single string and copy everything in.
@@ -371,7 +336,7 @@
     refs_len = 0
     if have_reference_lists:
         # Figure out how many bytes it will take to store the references
-        ref_lists = node[3]# <object>PyTuple_GET_ITEM_ptr_object(node, 3)
+        ref_lists = <object>PyTuple_GET_ITEM_ptr_object(node, 3)
         next_len = len(ref_lists) # TODO: use a Py function
         if next_len > 0:
             # If there are no nodes, we don't need to do any work
@@ -385,32 +350,31 @@
                     # references
                     refs_len = refs_len + (next_len - 1)
                     for reference in ref_list:
-                        if (not PyTuple_CheckExact(reference)
-                            and not StaticTuple_CheckExact(reference)):
+                        if not PyTuple_CheckExact(reference):
                             raise TypeError(
                                 'We expect references to be tuples not: %s'
                                 % type(reference))
-                        next_len = len(reference)
+                        next_len = PyTuple_GET_SIZE(reference)
                         if next_len > 0:
                             # We will need (len - 1) '\x00' characters to
                             # separate the reference key
                             refs_len = refs_len + (next_len - 1)
                             for i from 0 <= i < next_len:
-                                ref_bit = reference[i]
-                                if not PyString_CheckExact(ref_bit):
+                                ref_bit = PyTuple_GET_ITEM_ptr_object(reference, i)
+                                if not PyString_CheckExact_ptr(ref_bit):
                                     raise TypeError('We expect reference bits'
                                         ' to be strings not: %s'
                                         % type(<object>ref_bit))
-                                refs_len = refs_len + PyString_GET_SIZE(ref_bit)
+                                refs_len = refs_len + PyString_GET_SIZE_ptr(ref_bit)
 
     # So we have the (key NULL refs NULL value LF)
     key_len = PyString_Size(string_key)
-    val = node[2] # PyTuple_GET_ITEM_ptr_object(node, 2)
-    if not PyString_CheckExact(val):
+    val = PyTuple_GET_ITEM_ptr_object(node, 2)
+    if not PyString_CheckExact_ptr(val):
         raise TypeError('Expected a plain str for value not: %s'
-                        % type(val))
-    value = PyString_AS_STRING(val)
-    value_len = PyString_GET_SIZE(val)
+                        % type(<object>val))
+    value = PyString_AS_STRING_ptr(val)
+    value_len = PyString_GET_SIZE_ptr(val)
     flat_len = (key_len + 1 + refs_len + 1 + value_len + 1)
     line = PyString_FromStringAndSize(NULL, flat_len)
     # Get a pointer to the new buffer
@@ -432,14 +396,14 @@
                     out[0] = c'\r'
                     out = out + 1
                 first_reference = 0
-                next_len = len(reference)
+                next_len = PyTuple_GET_SIZE(reference)
                 for i from 0 <= i < next_len:
                     if i != 0:
                         out[0] = c'\x00'
                         out = out + 1
-                    ref_bit = reference[i] #PyTuple_GET_ITEM_ptr_object(reference, i)
-                    ref_bit_len = PyString_GET_SIZE(ref_bit)
-                    memcpy(out, PyString_AS_STRING(ref_bit), ref_bit_len)
+                    ref_bit = PyTuple_GET_ITEM_ptr_object(reference, i)
+                    ref_bit_len = PyString_GET_SIZE_ptr(ref_bit)
+                    memcpy(out, PyString_AS_STRING_ptr(ref_bit), ref_bit_len)
                     out = out + ref_bit_len
     out[0] = c'\0'
     out = out  + 1

=== modified file 'bzrlib/_chk_map_py.py'
--- bzrlib/_chk_map_py.py	2009-09-30 21:53:59 +0000
+++ bzrlib/_chk_map_py.py	2009-10-08 04:35:01 +0000
@@ -156,5 +156,3 @@
     result._search_prefix = common_prefix
     return result
 
-
-_key_type = tuple

=== modified file 'bzrlib/_chk_map_pyx.pyx'
--- bzrlib/_chk_map_pyx.pyx	2009-10-07 18:53:41 +0000
+++ bzrlib/_chk_map_pyx.pyx	2009-10-08 04:35:01 +0000
@@ -59,21 +59,9 @@
 
     uLong crc32(uLong crc, Bytef *buf, uInt len)
 
-# It seems we need to import the definitions so that the pyrex compiler has
-# local names to access them.
-from _static_tuple_c cimport StaticTuple,\
-    import_static_tuple_c, StaticTuple_New, \
-    StaticTuple_Intern, StaticTuple_SET_ITEM, StaticTuple_CheckExact
-
-
-# This sets up the StaticTuple C_API functionality
-import_static_tuple_c()
-
-cdef object _LeafNode
+
 _LeafNode = None
-cdef object _InternalNode
 _InternalNode = None
-cdef object _unknown
 _unknown = None
 
 # We shouldn't just copy this from _dirstate_helpers_pyx
@@ -101,11 +89,11 @@
     cdef uInt crc_val
     cdef Py_ssize_t out_off
     cdef char *c_out
-    # cdef PyObject *bit
+    cdef PyObject *bit
 
-    if not PyTuple_CheckExact(key) and not StaticTuple_CheckExact(key):
+    if not PyTuple_CheckExact(key):
         raise TypeError('key %r is not a tuple' % (key,))
-    num_bits = len(key)
+    num_bits = PyTuple_GET_SIZE(key)
     # 4 bytes per crc32, and another 1 byte between bits
     num_out_bytes = (9 * num_bits) - 1
     out = PyString_FromStringAndSize(NULL, num_out_bytes)
@@ -117,13 +105,11 @@
         # We use the _ptr variant, because GET_ITEM returns a borrowed
         # reference, and Pyrex assumes that returned 'object' are a new
         # reference
-        # XXX: This needs to be updated for PySequence_GetItem since both
-        #      PyTuple and StaticTuple support that api
-        bit = key[i]# PyTuple_GET_ITEM_ptr(key, i)
-        if not PyString_CheckExact(bit):
+        bit = PyTuple_GET_ITEM_ptr(key, i)
+        if not PyString_CheckExact_ptr(bit):
             raise TypeError('Bit %d of %r is not a string' % (i, key))
-        c_bit = <Bytef *>PyString_AS_STRING(bit)
-        c_len = PyString_GET_SIZE(bit)
+        c_bit = <Bytef *>PyString_AS_STRING_ptr(bit)
+        c_len = PyString_GET_SIZE_ptr(bit)
         crc_val = crc32(0, c_bit, c_len)
         # Hex(val) order
         sprintf(c_out, '%08X', crc_val)
@@ -141,11 +127,11 @@
     cdef uInt crc_val
     cdef Py_ssize_t out_off
     cdef char *c_out
-    # cdef PyObject *bit
+    cdef PyObject *bit
 
-    if not PyTuple_CheckExact(key) and not StaticTuple_CheckExact(key):
+    if not PyTuple_CheckExact(key):
         raise TypeError('key %r is not a tuple' % (key,))
-    num_bits = len(key)
+    num_bits = PyTuple_GET_SIZE(key)
     # 4 bytes per crc32, and another 1 byte between bits
     num_out_bytes = (5 * num_bits) - 1
     out = PyString_FromStringAndSize(NULL, num_out_bytes)
@@ -154,12 +140,12 @@
         if i > 0:
             c_out[0] = c'\x00'
             c_out = c_out + 1
-        bit = key[i] # PyTuple_GET_ITEM_ptr(key, i)
-        if not PyString_CheckExact(bit):
+        bit = PyTuple_GET_ITEM_ptr(key, i)
+        if not PyString_CheckExact_ptr(bit):
             raise TypeError('Bit %d of %r is not a string: %r' % (i, key,
-            bit))
-        c_bit = <Bytef *>PyString_AS_STRING(bit)
-        c_len = PyString_GET_SIZE(bit)
+            <object>bit))
+        c_bit = <Bytef *>PyString_AS_STRING_ptr(bit)
+        c_len = PyString_GET_SIZE_ptr(bit)
         crc_val = crc32(0, c_bit, c_len)
         # MSB order
         c_out[0] = (crc_val >> 24) & 0xFF
@@ -209,7 +195,6 @@
     cdef char *prefix, *value_start, *prefix_tail
     cdef char *next_null, *last_null, *line_start
     cdef char *c_entry, *entry_start
-    cdef StaticTuple entry_bits
 
     if _LeafNode is None:
         from bzrlib import chk_map
@@ -280,12 +265,12 @@
             if next_line == NULL:
                 raise ValueError('missing trailing newline')
             cur = next_line + 1
-        entry_bits = StaticTuple_New(width)
+        entry_bits = PyTuple_New(width)
         for i from 0 <= i < num_prefix_bits:
             entry = prefix_bits[i]
             # SET_ITEM 'steals' a reference
             Py_INCREF(entry)
-            StaticTuple_SET_ITEM(entry_bits, i, entry)
+            PyTuple_SET_ITEM(entry_bits, i, entry)
         value = PyString_FromStringAndSize(value_start, next_line - value_start)
         # The next entry bit needs the 'tail' from the prefix, and first part
         # of the line
@@ -303,7 +288,7 @@
             memcpy(c_entry + prefix_tail_len, line_start, next_null - line_start)
         Py_INCREF(entry)
         i = num_prefix_bits
-        StaticTuple_SET_ITEM(entry_bits, i, entry)
+        PyTuple_SET_ITEM(entry_bits, i, entry)
         while next_null != last_null: # We have remaining bits
             i = i + 1
             if i > width:
@@ -316,12 +301,11 @@
             entry = PyString_FromStringAndSize(entry_start,
                                                next_null - entry_start)
             Py_INCREF(entry)
-            StaticTuple_SET_ITEM(entry_bits, i, entry)
+            PyTuple_SET_ITEM(entry_bits, i, entry)
         if len(entry_bits) != width:
             raise AssertionError(
                 'Incorrect number of elements (%d vs %d)'
                 % (len(entry_bits)+1, width + 1))
-        entry_bits = StaticTuple_Intern(entry_bits)
         PyDict_SetItem(items, entry_bits, value)
     if len(items) != length:
         raise ValueError("item count (%d) mismatch for key %s,"
@@ -400,8 +384,7 @@
         memcpy(c_item_prefix + prefix_length, cur, next_null - cur)
         flat_key = PyString_FromStringAndSize(next_null + 1,
                                               next_line - next_null - 1)
-        flat_key = StaticTuple(flat_key).intern()
-        PyDict_SetItem(items, item_prefix, flat_key)
+        PyDict_SetItem(items, item_prefix, (flat_key,))
         cur = next_line + 1
     assert len(items) > 0
     result._items = items
@@ -416,5 +399,3 @@
     result._search_prefix = PyString_FromStringAndSize(prefix, prefix_length)
     return result
 
-
-_key_type = StaticTuple

=== modified file 'bzrlib/_simple_set_pyx.pxd'
--- bzrlib/_simple_set_pyx.pxd	2009-10-07 19:31:39 +0000
+++ bzrlib/_simple_set_pyx.pxd	2009-10-08 04:40:16 +0000
@@ -27,6 +27,7 @@
     ctypedef struct PyObject:
         pass
 
+
 cdef public api class SimpleSet [object SimpleSetObject, type SimpleSet_Type]:
     """A class similar to PySet, but with simpler implementation.
 
@@ -53,7 +54,14 @@
     cdef int _insert_clean(self, PyObject *key) except -1
     cdef Py_ssize_t _resize(self, Py_ssize_t min_unused) except -1
 
+
 # TODO: might want to export the C api here, though it is all available from
 #       the class object...
 cdef api object SimpleSet_Add(object self, object key)
 cdef api SimpleSet SimpleSet_New()
+cdef api object SimpleSet_Add(object self, object key)
+cdef api int SimpleSet_Contains(object self, object key) except -1
+cdef api int SimpleSet_Discard(object self, object key) except -1
+cdef api PyObject *SimpleSet_Get(SimpleSet self, object key) except? NULL
+cdef api Py_ssize_t SimpleSet_Size(object self) except -1
+cdef api int SimpleSet_Next(object self, Py_ssize_t *pos, PyObject **key)

=== modified file 'bzrlib/_simple_set_pyx.pyx'
--- bzrlib/_simple_set_pyx.pyx	2009-10-07 21:17:47 +0000
+++ bzrlib/_simple_set_pyx.pyx	2009-10-08 04:40:16 +0000
@@ -38,6 +38,7 @@
     void PyMem_Free(void *)
     void memset(void *, int, size_t)
 
+
 cdef object _dummy_obj
 cdef PyObject *_dummy
 _dummy_obj = object()

=== removed file 'bzrlib/_static_tuple_c.c'
--- bzrlib/_static_tuple_c.c	2009-10-07 19:31:39 +0000
+++ bzrlib/_static_tuple_c.c	1970-01-01 00:00:00 +0000
@@ -1,671 +0,0 @@
-/* Copyright (C) 2009 Canonical Ltd
- * 
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- */
-
-/* Must be defined before importing _static_tuple_c.h so that we get the right
- * linkage.
- */
-#define STATIC_TUPLE_MODULE
-
-#include "_static_tuple_c.h"
-#include "_export_c_api.h"
-#include "_simple_set_pyx_api.h"
-
-#include "python-compat.h"
-
-#if defined(__GNUC__)
-#   define inline __inline__
-#elif defined(_MSC_VER)
-#   define inline __inline
-#else
-#   define inline
-#endif
-
-
-/* The one and only StaticTuple with no values */
-static StaticTuple *_empty_tuple = NULL;
-static PyObject *_interned_tuples = NULL;
-
-
-static inline int
-_StaticTuple_is_interned(StaticTuple *self)
-{
-    return self->flags & STATIC_TUPLE_INTERNED_FLAG;
-}
-
-
-
-static PyObject *
-StaticTuple_as_tuple(StaticTuple *self)
-{
-    PyObject *tpl = NULL, *obj = NULL;
-    int i, len;
-
-    len = self->size;
-    tpl = PyTuple_New(len);
-    if (!tpl) {
-        /* Malloc failure */
-        return NULL;
-    }
-    for (i = 0; i < len; ++i) {
-        obj = (PyObject *)self->items[i];
-        Py_INCREF(obj);
-        PyTuple_SET_ITEM(tpl, i, obj);
-    }
-    return tpl;
-}
-
-
-static char StaticTuple_as_tuple_doc[] = "as_tuple() => tuple";
-
-static StaticTuple *
-StaticTuple_Intern(StaticTuple *self)
-{
-    PyObject *unique_key = NULL;
-
-    if (_interned_tuples == NULL || _StaticTuple_is_interned(self)) {
-        Py_INCREF(self);
-        return self;
-    }
-    /* SimpleSet_Add returns whatever object is present at self
-     * or the new object if it needs to add it.
-     */
-    unique_key = SimpleSet_Add(_interned_tuples, (PyObject *)self);
-    if (!unique_key) {
-        // Suppress any error and just return the object
-        PyErr_Clear();
-        Py_INCREF(self);
-        return self;
-    }
-    if (unique_key != (PyObject *)self) {
-        // There was already a key at that location
-        return (StaticTuple *)unique_key;
-    }
-    self->flags |= STATIC_TUPLE_INTERNED_FLAG;
-    // The two references in the dict do not count, so that the StaticTuple object
-    // does not become immortal just because it was interned.
-    Py_REFCNT(self) -= 1;
-    return self;
-}
-
-static char StaticTuple_Intern_doc[] = "intern() => unique StaticTuple\n"
-    "Return a 'canonical' StaticTuple object.\n"
-    "Similar to intern() for strings, this makes sure there\n"
-    "is only one StaticTuple object for a given value\n."
-    "Common usage is:\n"
-    "  key = StaticTuple('foo', 'bar').intern()\n";
-
-
-static void
-StaticTuple_dealloc(StaticTuple *self)
-{
-    int i, len;
-
-    if (_StaticTuple_is_interned(self)) {
-        /* revive dead object temporarily for Discard */
-        Py_REFCNT(self) = 2;
-        if (SimpleSet_Discard(_interned_tuples, (PyObject*)self) != 1)
-            Py_FatalError("deletion of interned StaticTuple failed");
-        self->flags &= ~STATIC_TUPLE_INTERNED_FLAG;
-    }
-    len = self->size;
-    for (i = 0; i < len; ++i) {
-        Py_XDECREF(self->items[i]);
-    }
-    Py_TYPE(self)->tp_free((PyObject *)self);
-}
-
-
-/* Similar to PyTuple_New() */
-static StaticTuple *
-StaticTuple_New(Py_ssize_t size)
-{
-    StaticTuple *stuple;
-    if (size < 0) {
-        PyErr_BadInternalCall();
-        return NULL;
-    }
-
-    if (size == 0 && _empty_tuple != NULL) {
-        Py_INCREF(_empty_tuple);
-        return _empty_tuple;
-    }
-    /* Note that we use PyObject_NewVar because we want to allocate a variable
-     * width entry. However we *aren't* truly a PyVarObject because we don't
-     * use a long for ob_size. Instead we use a plain 'size' that is an int,
-     * and will be overloaded with flags in the future.
-     * As such we do the alloc, and then have to clean up anything it does
-     * incorrectly.
-     */
-    stuple = PyObject_NewVar(StaticTuple, &StaticTuple_Type, size);
-    if (stuple == NULL) {
-        return NULL;
-    }
-    stuple->size = size;
-    stuple->flags = 0;
-    stuple->_unused0 = 0;
-    stuple->_unused1 = 0;
-    if (size > 0) {
-        memset(stuple->items, 0, sizeof(PyObject *) * size);
-    }
-#if STATIC_TUPLE_HAS_HASH
-    stuple->hash = -1;
-#endif
-    return stuple;
-}
-
-
-static PyObject *
-StaticTuple_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
-{
-    StaticTuple *self;
-    PyObject *obj = NULL;
-    Py_ssize_t i, len = 0;
-
-    if (type != &StaticTuple_Type) {
-        PyErr_SetString(PyExc_TypeError, "we only support creating StaticTuple");
-        return NULL;
-    }
-    if (!PyTuple_CheckExact(args)) {
-        PyErr_SetString(PyExc_TypeError, "args must be a tuple");
-        return NULL;
-    }
-    len = PyTuple_GET_SIZE(args);
-    if (len < 0 || len > 255) {
-        /* Too big or too small */
-        PyErr_SetString(PyExc_ValueError, "StaticTuple.__init__(...)"
-            " takes from 0 to 255 key bits");
-        return NULL;
-    }
-    self = (StaticTuple *)StaticTuple_New(len);
-    if (self == NULL) {
-        return NULL;
-    }
-    for (i = 0; i < len; ++i) {
-        obj = PyTuple_GET_ITEM(args, i);
-        if (!PyString_CheckExact(obj)) {
-            if (!StaticTuple_CheckExact(obj)) {
-                PyErr_SetString(PyExc_TypeError, "StaticTuple.__init__(...)"
-                    " requires that all key bits are strings or StaticTuple.");
-                /* TODO: What is the proper way to dealloc ? */
-                type->tp_dealloc((PyObject *)self);
-                return NULL;
-            }
-        }
-        Py_INCREF(obj);
-        self->items[i] = obj;
-    }
-    return (PyObject *)self;
-}
-
-static PyObject *
-StaticTuple_repr(StaticTuple *self)
-{
-    PyObject *as_tuple, *tuple_repr, *result;
-
-    as_tuple = StaticTuple_as_tuple(self);
-    if (as_tuple == NULL) {
-        return NULL;
-    }
-    tuple_repr = PyObject_Repr(as_tuple);
-    Py_DECREF(as_tuple);
-    if (tuple_repr == NULL) {
-        return NULL;
-    }
-    result = PyString_FromFormat("%s%s", Py_TYPE(self)->tp_name,
-                                         PyString_AsString(tuple_repr));
-    return result;
-}
-
-static long
-StaticTuple_hash(StaticTuple *self)
-{
-    /* adapted from tuplehash(), is the specific hash value considered
-     * 'stable'?
-     */
-	register long x, y;
-	Py_ssize_t len = self->size;
-	PyObject **p;
-	long mult = 1000003L;
-
-#if STATIC_TUPLE_HAS_HASH
-    if (self->hash != -1) {
-        return self->hash;
-    }
-#endif
-	x = 0x345678L;
-	p = self->items;
-    // TODO: We could set specific flags if we know that, for example, all the
-    //       keys are strings. I haven't seen a real-world benefit to that yet,
-    //       though.
-    while (--len >= 0) {
-        y = PyObject_Hash(*p++);
-        if (y == -1) /* failure */
-            return -1;
-        x = (x ^ y) * mult;
-        /* the cast might truncate len; that doesn't change hash stability */
-        mult += (long)(82520L + len + len);
-    }
-	x += 97531L;
-	if (x == -1)
-		x = -2;
-#if STATIC_TUPLE_HAS_HASH
-    if (self->hash != -1) {
-        if (self->hash != x) {
-            fprintf(stderr, "hash changed: %d => %d\n", self->hash, x);
-        }
-    }
-    self->hash = x;
-#endif
-	return x;
-}
-
-static PyObject *
-StaticTuple_richcompare_to_tuple(StaticTuple *v, PyObject *wt, int op)
-{
-    PyObject *vt;
-    PyObject *result = NULL;
-    
-    vt = StaticTuple_as_tuple((StaticTuple *)v);
-    if (vt == NULL) {
-        goto Done;
-    }
-    if (!PyTuple_Check(wt)) {
-        PyErr_BadInternalCall();
-        result = NULL;
-        goto Done;
-    }
-    /* Now we have 2 tuples to compare, do it */
-    result = PyTuple_Type.tp_richcompare(vt, wt, op);
-Done:
-    Py_XDECREF(vt);
-    return result;
-}
-
-
-static PyObject *
-StaticTuple_richcompare(PyObject *v, PyObject *w, int op)
-{
-    StaticTuple *vk, *wk;
-    Py_ssize_t vlen, wlen, min_len, i;
-    PyObject *v_obj, *w_obj;
-    richcmpfunc string_richcompare;
-
-    if (!StaticTuple_CheckExact(v)) {
-        /* This has never triggered, according to python-dev it seems this
-         * might trigger if '__op__' is defined but '__rop__' is not, sort of
-         * case. Such as "None == StaticTuple()"
-         */
-        fprintf(stderr, "self is not StaticTuple\n");
-        Py_INCREF(Py_NotImplemented);
-        return Py_NotImplemented;
-    }
-    vk = (StaticTuple *)v;
-    if (StaticTuple_CheckExact(w)) {
-        /* The most common case */
-        wk = (StaticTuple*)w;
-    } else if (PyTuple_Check(w)) {
-        /* One of v or w is a tuple, so we go the 'slow' route and cast up to
-         * tuples to compare.
-         */
-        /* TODO: This seems to be triggering more than I thought it would...
-         *       We probably want to optimize comparing self to other when
-         *       other is a tuple.
-         */
-        return StaticTuple_richcompare_to_tuple(vk, w, op);
-    } else if (w == Py_None) {
-        // None is always less than the object
-		switch (op) {
-		case Py_NE:case Py_GT:case Py_GE:
-            Py_INCREF(Py_True);
-            return Py_True;
-        case Py_EQ:case Py_LT:case Py_LE:
-            Py_INCREF(Py_False);
-            return Py_False;
-		}
-    } else {
-        /* We don't special case this comparison, we just let python handle
-         * it.
-         */
-         Py_INCREF(Py_NotImplemented);
-         return Py_NotImplemented;
-    }
-    /* Now we know that we have 2 StaticTuple objects, so let's compare them.
-     * This code is somewhat borrowed from tuplerichcompare, except we know our
-     * objects are limited in scope, so we can inline some comparisons.
-     */
-    if (v == w) {
-        /* Identical pointers, we can shortcut this easily. */
-		switch (op) {
-		case Py_EQ:case Py_LE:case Py_GE:
-            Py_INCREF(Py_True);
-            return Py_True;
-		case Py_NE:case Py_LT:case Py_GT:
-            Py_INCREF(Py_False);
-            return Py_False;
-		}
-    }
-    /* TODO: if STATIC_TUPLE_INTERNED_FLAG is set on both objects and they are
-     *       not the same pointer, then we know they aren't the same object
-     *       without having to do sub-by-sub comparison.
-     */
-
-    /* It will be rare that we compare tuples of different lengths, so we don't
-     * start by optimizing the length comparision, same as the tuple code
-     * TODO: Interning may change this, because we'll be comparing lots of
-     *       different StaticTuple objects in the intern dict
-     */
-    vlen = vk->size;
-    wlen = wk->size;
-	min_len = (vlen < wlen) ? vlen : wlen;
-    string_richcompare = PyString_Type.tp_richcompare;
-    for (i = 0; i < min_len; i++) {
-        PyObject *result = NULL;
-        v_obj = StaticTuple_GET_ITEM(vk, i);
-        w_obj = StaticTuple_GET_ITEM(wk, i);
-        if (PyString_CheckExact(v_obj) && PyString_CheckExact(w_obj)) {
-            result = string_richcompare(v_obj, w_obj, Py_EQ);
-        } else if (StaticTuple_CheckExact(v_obj) &&
-                   StaticTuple_CheckExact(w_obj))
-        {
-            /* Both are StaticTuple types, so recurse */
-            result = StaticTuple_richcompare(v_obj, w_obj, Py_EQ);
-        } else {
-            /* Not the same type, obviously they won't compare equal */
-            break;
-        }
-        if (result == NULL) {
-            return NULL; /* There seems to be an error */
-        }
-        if (result == Py_NotImplemented) {
-            PyErr_BadInternalCall();
-            Py_DECREF(result);
-            return NULL;
-        }
-        if (result == Py_False) {
-            /* This entry is not identical
-             * Shortcut for Py_EQ
-             */
-            if (op == Py_EQ) {
-                return result;
-            }
-            Py_DECREF(result);
-            break;
-        }
-        if (result != Py_True) {
-            /* We don't know *what* richcompare is returning, but it
-             * isn't something we recognize
-             */
-            PyErr_BadInternalCall();
-            Py_DECREF(result);
-            return NULL;
-        }
-        Py_DECREF(result);
-    }
-	if (i >= vlen || i >= wlen) {
-        /* We walked off one of the lists, but everything compared equal so
-         * far. Just compare the size.
-         */
-		int cmp;
-		PyObject *res;
-		switch (op) {
-		case Py_LT: cmp = vlen <  wlen; break;
-		case Py_LE: cmp = vlen <= wlen; break;
-		case Py_EQ: cmp = vlen == wlen; break;
-		case Py_NE: cmp = vlen != wlen; break;
-		case Py_GT: cmp = vlen >  wlen; break;
-		case Py_GE: cmp = vlen >= wlen; break;
-		default: return NULL; /* cannot happen */
-		}
-		if (cmp)
-			res = Py_True;
-		else
-			res = Py_False;
-		Py_INCREF(res);
-		return res;
-	}
-    /* The last item differs, shortcut the Py_NE case */
-    if (op == Py_NE) {
-        Py_INCREF(Py_True);
-        return Py_True;
-    }
-    /* It is some other comparison, go ahead and do the real check. */
-    if (PyString_CheckExact(v_obj) && PyString_CheckExact(w_obj))
-    {
-        return string_richcompare(v_obj, w_obj, op);
-    } else if (StaticTuple_CheckExact(v_obj) &&
-               StaticTuple_CheckExact(w_obj))
-    {
-        /* Both are StaticTuple types, so recurse */
-        return StaticTuple_richcompare(v_obj, w_obj, op);
-    } else {
-        Py_INCREF(Py_NotImplemented);
-        return Py_NotImplemented;
-    }
-}
-
-
-static Py_ssize_t
-StaticTuple_length(StaticTuple *self)
-{
-    return self->size;
-}
-
-
-static PyObject *
-StaticTuple__is_interned(StaticTuple *self)
-{
-    if (_StaticTuple_is_interned(self)) {
-        Py_INCREF(Py_True);
-        return Py_True;
-    }
-    Py_INCREF(Py_False);
-    return Py_False;
-}
-
-static char StaticTuple__is_interned_doc[] = "_is_interned() => True/False\n"
-    "Check to see if this key has been interned.\n";
-
-
-static PyObject *
-StaticTuple_item(StaticTuple *self, Py_ssize_t offset)
-{
-    PyObject *obj;
-    if (offset < 0 || offset >= self->size) {
-        PyErr_SetString(PyExc_IndexError, "StaticTuple index out of range");
-        return NULL;
-    }
-    obj = (PyObject *)self->items[offset];
-    Py_INCREF(obj);
-    return obj;
-}
-
-static PyObject *
-StaticTuple_slice(StaticTuple *self, Py_ssize_t ilow, Py_ssize_t ihigh)
-{
-    PyObject *as_tuple, *result;
-
-    as_tuple = StaticTuple_as_tuple(self);
-    if (as_tuple == NULL) {
-        return NULL;
-    }
-    result = PyTuple_Type.tp_as_sequence->sq_slice(as_tuple, ilow, ihigh);
-    Py_DECREF(as_tuple);
-    return result;
-}
-
-static int
-StaticTuple_traverse(StaticTuple *self, visitproc visit, void *arg)
-{
-    Py_ssize_t i;
-    for (i = self->size; --i >= 0;) {
-        Py_VISIT(self->items[i]);
-    }
-    return 0;
-}
-
-static char StaticTuple_doc[] =
-    "C implementation of a StaticTuple structure."
-    "\n This is used as StaticTuple(key_bit_1, key_bit_2, key_bit_3, ...)"
-    "\n This is similar to tuple, just less flexible in what it"
-    "\n supports, but also lighter memory consumption.";
-
-static PyMethodDef StaticTuple_methods[] = {
-    {"as_tuple", (PyCFunction)StaticTuple_as_tuple, METH_NOARGS, StaticTuple_as_tuple_doc},
-    {"intern", (PyCFunction)StaticTuple_Intern, METH_NOARGS, StaticTuple_Intern_doc},
-    {"_is_interned", (PyCFunction)StaticTuple__is_interned, METH_NOARGS,
-     StaticTuple__is_interned_doc},
-    {NULL, NULL} /* sentinel */
-};
-
-static PySequenceMethods StaticTuple_as_sequence = {
-    (lenfunc)StaticTuple_length,            /* sq_length */
-    0,                              /* sq_concat */
-    0,                              /* sq_repeat */
-    (ssizeargfunc)StaticTuple_item,         /* sq_item */
-    (ssizessizeargfunc)StaticTuple_slice,   /* sq_slice */
-    0,                              /* sq_ass_item */
-    0,                              /* sq_ass_slice */
-    0,                              /* sq_contains */
-};
-
-
-PyTypeObject StaticTuple_Type = {
-    PyObject_HEAD_INIT(NULL)
-    0,                                           /* ob_size */
-    "StaticTuple",                               /* tp_name */
-    sizeof(StaticTuple),                         /* tp_basicsize */
-    sizeof(PyObject *),                          /* tp_itemsize */
-    (destructor)StaticTuple_dealloc,             /* tp_dealloc */
-    0,                                           /* tp_print */
-    0,                                           /* tp_getattr */
-    0,                                           /* tp_setattr */
-    0,                                           /* tp_compare */
-    (reprfunc)StaticTuple_repr,                  /* tp_repr */
-    0,                                           /* tp_as_number */
-    &StaticTuple_as_sequence,                    /* tp_as_sequence */
-    0,                                           /* tp_as_mapping */
-    (hashfunc)StaticTuple_hash,                  /* tp_hash */
-    0,                                           /* tp_call */
-    0,                                           /* tp_str */
-    PyObject_GenericGetAttr,                     /* tp_getattro */
-    0,                                           /* tp_setattro */
-    0,                                           /* tp_as_buffer */
-    Py_TPFLAGS_DEFAULT,                          /* tp_flags*/
-    StaticTuple_doc,                             /* tp_doc */
-    /* gc.get_referents checks the IS_GC flag before it calls tp_traverse
-     * And we don't include this object in the garbage collector because we
-     * know it doesn't create cycles. However, 'meliae' will follow
-     * tp_traverse, even if the object isn't GC, and we want that.
-     */
-    (traverseproc)StaticTuple_traverse,          /* tp_traverse */
-    0,                                           /* tp_clear */
-    StaticTuple_richcompare,                     /* tp_richcompare */
-    0,                                           /* tp_weaklistoffset */
-    // without implementing tp_iter, Python will fall back to PySequence*
-    // which seems to work ok, we may need something faster/lighter in the
-    // future.
-    0,                                           /* tp_iter */
-    0,                                           /* tp_iternext */
-    StaticTuple_methods,                         /* tp_methods */
-    0,                                           /* tp_members */
-    0,                                           /* tp_getset */
-    0,                                           /* tp_base */
-    0,                                           /* tp_dict */
-    0,                                           /* tp_descr_get */
-    0,                                           /* tp_descr_set */
-    0,                                           /* tp_dictoffset */
-    0,                                           /* tp_init */
-    0,                                           /* tp_alloc */
-    StaticTuple_new,                             /* tp_new */
-};
-
-
-static PyMethodDef static_tuple_c_methods[] = {
-    {NULL, NULL}
-};
-
-
-static void
-setup_interned_tuples(PyObject *m)
-{
-    _interned_tuples = (PyObject *)SimpleSet_New();
-    if (_interned_tuples != NULL) {
-        Py_INCREF(_interned_tuples);
-        PyModule_AddObject(m, "_interned_tuples", _interned_tuples);
-    }
-}
-
-
-static void
-setup_empty_tuple(PyObject *m)
-{
-    StaticTuple *stuple;
-    if (_interned_tuples == NULL) {
-        fprintf(stderr, "You need to call setup_interned_tuples() before"
-                " setup_empty_tuple, because we intern it.\n");
-    }
-    // We need to create the empty tuple
-    stuple = (StaticTuple *)StaticTuple_New(0);
-    _empty_tuple = StaticTuple_Intern(stuple);
-    assert(_empty_tuple == stuple);
-    // At this point, refcnt is 2: 1 from New(), and 1 from the return from
-    // intern(). We will keep 1 for the _empty_tuple global, and use the other
-    // for the module reference.
-    PyModule_AddObject(m, "_empty_tuple", (PyObject *)_empty_tuple);
-}
-
-static int
-_StaticTuple_CheckExact(PyObject *obj)
-{
-    return StaticTuple_CheckExact(obj);
-}
-
-static void
-setup_c_api(PyObject *m)
-{
-    _export_function(m, "StaticTuple_New", StaticTuple_New,
-        "StaticTuple *(Py_ssize_t)");
-    _export_function(m, "StaticTuple_Intern", StaticTuple_Intern,
-        "StaticTuple *(StaticTuple *)");
-    _export_function(m, "_StaticTuple_CheckExact", _StaticTuple_CheckExact,
-        "int(PyObject *)");
-}
-
-
-PyMODINIT_FUNC
-init_static_tuple_c(void)
-{
-    PyObject* m;
-
-    if (PyType_Ready(&StaticTuple_Type) < 0)
-        return;
-
-    m = Py_InitModule3("_static_tuple_c", static_tuple_c_methods,
-                       "C implementation of a StaticTuple structure");
-    if (m == NULL)
-      return;
-
-    Py_INCREF(&StaticTuple_Type);
-    PyModule_AddObject(m, "StaticTuple", (PyObject *)&StaticTuple_Type);
-    if (import_bzrlib___simple_set_pyx() == -1) {
-        // We failed to set up, stop early
-        return;
-    }
-    setup_interned_tuples(m);
-    setup_empty_tuple(m);
-    setup_c_api(m);
-}

=== removed file 'bzrlib/_static_tuple_c.h'
--- bzrlib/_static_tuple_c.h	2009-10-07 15:57:25 +0000
+++ bzrlib/_static_tuple_c.h	1970-01-01 00:00:00 +0000
@@ -1,112 +0,0 @@
-/* Copyright (C) 2009 Canonical Ltd
- * 
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- */
-
-#ifndef _STATIC_TUPLE_H_
-#define _STATIC_TUPLE_H_
-#include <Python.h>
-#include <string.h>
-
-#define STATIC_TUPLE_HAS_HASH 0
-/* Caching the hash adds memory, but allows us to save a little time during
- * lookups. TIMEIT hash(key) shows it as
- *  0.108usec w/ hash
- *  0.160usec w/o hash
- * Note that the entries themselves are strings, which already cache their
- * hashes. So while there is a 1.5:1 difference in the time for hash(), it is
- * already a function which is quite fast. Probably the only reason we might
- * want to do so, is if we customized SimpleSet to the point that the item
- * pointers were exactly certain types, and then accessed table[i]->hash
- * directly. So far StaticTuple_hash() is fast enough to not warrant the memory
- * difference.
- */
-
-/* This defines a single variable-width key.
- * It is basically the same as a tuple, but
- * 1) Lighter weight in memory
- * 2) Only supports strings or other static types (that don't reference other
- *    objects.)
- */
-
-#define STATIC_TUPLE_INTERNED_FLAG 0x01
-typedef struct {
-    PyObject_HEAD
-    // We could go with unsigned short here, and support 64k width tuples
-    // without any memory impact, might be worthwhile
-    unsigned char size;
-    unsigned char flags;
-    unsigned char _unused0;
-    unsigned char _unused1;
-    // Note that on 64-bit, we actually have 4-more unused bytes
-    // because items will always be aligned to a 64-bit boundary
-#if STATIC_TUPLE_HAS_HASH
-    long hash;
-#endif
-    PyObject *items[0];
-} StaticTuple;
-extern PyTypeObject StaticTuple_Type;
-
-typedef struct {
-    PyObject_VAR_HEAD
-    PyObject *table[0];
-} KeyIntern;
-
-#define StaticTuple_SET_ITEM(key, offset, val) \
-    ((((StaticTuple*)(key))->items[(offset)]) = ((PyObject *)(val)))
-#define StaticTuple_GET_ITEM(key, offset) (((StaticTuple*)key)->items[offset])
-
-
-#ifdef STATIC_TUPLE_MODULE
-/* Used when compiling _static_tuple_c.c */
-
-static StaticTuple * StaticTuple_New(Py_ssize_t);
-static StaticTuple * StaticTuple_Intern(StaticTuple *self);
-#define StaticTuple_CheckExact(op) (Py_TYPE(op) == &StaticTuple_Type)
-
-#else
-/* Used as the foreign api */
-
-#include "_import_c_api.h"
-
-static StaticTuple *(*StaticTuple_New)(Py_ssize_t);
-static StaticTuple *(*StaticTuple_Intern)(StaticTuple *);
-static PyTypeObject *_p_StaticTuple_Type;
-
-#define StaticTuple_CheckExact(op) (Py_TYPE(op) == _p_StaticTuple_Type)
-static int (*_StaticTuple_CheckExact)(PyObject *);
-
-
-/* Return -1 and set exception on error, 0 on success */
-static int
-import_static_tuple_c(void)
-{
-    struct function_description functions[] = {
-        {"StaticTuple_New", (void **)&StaticTuple_New,
-            "StaticTuple *(Py_ssize_t)"},
-        {"StaticTuple_Intern", (void **)&StaticTuple_Intern,
-            "StaticTuple *(StaticTuple *)"},
-        {"_StaticTuple_CheckExact", (void **)&_StaticTuple_CheckExact,
-            "int(PyObject *)"},
-        {NULL}};
-    struct type_description types[] = {
-        {"StaticTuple", &_p_StaticTuple_Type},
-        {NULL}};
-    return _import_extension_module("bzrlib._static_tuple_c",
-        functions, types);
-}
-
-#endif // !STATIC_TUPLE_MODULE
-#endif // !_STATIC_TUPLE_H_

=== removed file 'bzrlib/_static_tuple_c.pxd'
--- bzrlib/_static_tuple_c.pxd	2009-10-07 15:57:25 +0000
+++ bzrlib/_static_tuple_c.pxd	1970-01-01 00:00:00 +0000
@@ -1,40 +0,0 @@
-# Copyright (C) 2009 Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
-"""The interface definition file for the StaticTuple class."""
-
-
-cdef extern from "Python.h":
-    ctypedef int Py_ssize_t # Required for older pyrex versions
-    ctypedef struct PyObject:
-        pass
-
-cdef extern from "_static_tuple_c.h":
-    ctypedef class bzrlib._static_tuple_c.StaticTuple [object StaticTuple]:
-        cdef unsigned char size
-        cdef unsigned char flags
-        cdef PyObject *items[0]
-
-    # Must be called before using any of the C api, as it sets the function
-    # pointers in memory.
-    int import_static_tuple_c() except -1
-    StaticTuple StaticTuple_New(Py_ssize_t)
-    StaticTuple StaticTuple_Intern(StaticTuple)
-
-    # Steals a reference and val must be a valid type, no checking is done
-    void StaticTuple_SET_ITEM(StaticTuple key, Py_ssize_t offset, object val)
-    object StaticTuple_GET_ITEM(StaticTuple key, Py_ssize_t offset)
-    int StaticTuple_CheckExact(object)

=== removed file 'bzrlib/_static_tuple_py.py'
--- bzrlib/_static_tuple_py.py	2009-10-07 16:12:50 +0000
+++ bzrlib/_static_tuple_py.py	1970-01-01 00:00:00 +0000
@@ -1,57 +0,0 @@
-# Copyright (C) 2009 Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
-"""The pure-python implementation of the StaticTuple type.
-
-Note that it is generally just implemented as using tuples of tuples of
-strings.
-"""
-
-
-class StaticTuple(tuple):
-    """A static type, similar to a tuple of strings."""
-
-    def __new__(cls, *args):
-        # Make the empty StaticTuple a singleton
-        if not args and _empty_tuple is not None:
-            return _empty_tuple
-        return tuple.__new__(cls, args)
-
-    def __init__(self, *args):
-        """Create a new 'StaticTuple'"""
-        for bit in args:
-            if type(bit) not in (str, StaticTuple):
-                raise TypeError('key bits must be strings or StaticTuple')
-        num_keys = len(args)
-        if num_keys < 0 or num_keys > 255:
-            raise ValueError('must have 1 => 256 key bits')
-        # We don't need to pass args to tuple.__init__, because that was
-        # already handled in __new__.
-        tuple.__init__(self)
-
-    def __repr__(self):
-        return '%s%s' % (self.__class__.__name__, tuple.__repr__(self))
-
-    def as_tuple(self):
-        return self
-
-    def intern(self):
-        return _interned_tuples.setdefault(self, self)
-
-
-_empty_tuple = None
-_empty_tuple = StaticTuple()
-_interned_tuples = {}

=== modified file 'bzrlib/chk_map.py'
--- bzrlib/chk_map.py	2009-10-07 19:35:09 +0000
+++ bzrlib/chk_map.py	2009-10-08 04:35:01 +0000
@@ -133,7 +133,7 @@
 
     def _ensure_root(self):
         """Ensure that the root node is an object not a key."""
-        if type(self._root_node) in (_key_type, tuple):
+        if type(self._root_node) is tuple:
             # Demand-load the root
             self._root_node = self._get_node(self._root_node)
 
@@ -147,7 +147,7 @@
         :param node: A tuple key or node object.
         :return: A node object.
         """
-        if type(node) in (tuple, _key_type):
+        if type(node) is tuple:
             bytes = self._read_bytes(node)
             return _deserialise(bytes, node,
                 search_key_func=self._search_key_func)
@@ -194,7 +194,7 @@
             for key, value in sorted(node._items.iteritems()):
                 # Don't use prefix nor indent here to line up when used in
                 # tests in conjunction with assertEqualDiff
-                result.append('      %r %r' % (tuple(key), value))
+                result.append('      %r %r' % (key, value))
         return result
 
     @classmethod
@@ -486,7 +486,7 @@
 
     def key(self):
         """Return the key for this map."""
-        if type(self._root_node) in (tuple, _key_type):
+        if type(self._root_node) is tuple:
             return self._root_node
         else:
             return self._root_node._key
@@ -516,7 +516,7 @@
 
     def _node_key(self, node):
         """Get the key for a node whether it's a tuple or node."""
-        if type(node) in (tuple, _key_type):
+        if type(node) is tuple:
             return node
         else:
             return node._key
@@ -542,7 +542,7 @@
 
         :return: The key of the root node.
         """
-        if type(self._root_node) in (tuple, _key_type):
+        if type(self._root_node) is tuple:
             # Already saved.
             return self._root_node
         keys = list(self._root_node.serialise(self._store))
@@ -1024,7 +1024,7 @@
             # for whatever we are missing
             shortcut = True
             for prefix, node in self._items.iteritems():
-                if node.__class__ in (tuple, _key_type):
+                if node.__class__ is tuple:
                     keys[node] = (prefix, None)
                 else:
                     yield node, None
@@ -1059,7 +1059,7 @@
                     # A given key can only match 1 child node, if it isn't
                     # there, then we can just return nothing
                     return
-                if node.__class__ in (tuple, _key_type):
+                if node.__class__ is tuple:
                     keys[node] = (search_prefix, [key])
                 else:
                     # This is loaded, and the only thing that can match,
@@ -1092,7 +1092,7 @@
                         # We can ignore this one
                         continue
                     node_key_filter = prefix_to_keys[search_prefix]
-                    if node.__class__ in (tuple, _key_type):
+                    if node.__class__ is tuple:
                         keys[node] = (search_prefix, node_key_filter)
                     else:
                         yield node, node_key_filter
@@ -1107,7 +1107,7 @@
                         if sub_prefix in length_filter:
                             node_key_filter.extend(prefix_to_keys[sub_prefix])
                     if node_key_filter: # this key matched something, yield it
-                        if node.__class__ in (tuple, _key_type):
+                        if node.__class__ is tuple:
                             keys[node] = (prefix, node_key_filter)
                         else:
                             yield node, node_key_filter
@@ -1245,7 +1245,7 @@
         :return: An iterable of the keys inserted by this operation.
         """
         for node in self._items.itervalues():
-            if type(node) in (tuple, _key_type):
+            if type(node) is tuple:
                 # Never deserialised.
                 continue
             if node._key is not None:
@@ -1262,7 +1262,7 @@
         lines.append('%s\n' % (self._search_prefix,))
         prefix_len = len(self._search_prefix)
         for prefix, node in sorted(self._items.items()):
-            if type(node) in (tuple, _key_type):
+            if type(node) is tuple:
                 key = node[0]
             else:
                 key = node._key[0]
@@ -1307,7 +1307,7 @@
             raise AssertionError("unserialised nodes have no refs.")
         refs = []
         for value in self._items.itervalues():
-            if type(value) in (tuple, _key_type):
+            if type(value) is tuple:
                 refs.append(value)
             else:
                 refs.append(value.key())
@@ -1639,7 +1639,6 @@
         _search_key_255,
         _deserialise_leaf_node,
         _deserialise_internal_node,
-        _key_type,
         )
 except ImportError, e:
     osutils.failed_to_load_extension(e)
@@ -1648,7 +1647,6 @@
         _search_key_255,
         _deserialise_leaf_node,
         _deserialise_internal_node,
-        _key_type,
         )
 search_key_registry.register('hash-16-way', _search_key_16)
 search_key_registry.register('hash-255-way', _search_key_255)

=== modified file 'bzrlib/index.py'
--- bzrlib/index.py	2009-10-07 15:27:24 +0000
+++ bzrlib/index.py	2009-10-08 04:35:01 +0000
@@ -40,7 +40,6 @@
     debug,
     errors,
     )
-from bzrlib._static_tuple_c import StaticTuple
 
 _HEADER_READV = (0, 200)
 _OPTION_KEY_ELEMENTS = "key_elements="
@@ -103,7 +102,7 @@
 
     def _check_key(self, key):
         """Raise BadIndexKey if key is not a valid key for this index."""
-        if type(key) not in (tuple, StaticTuple):
+        if type(key) != tuple:
             raise errors.BadIndexKey(key)
         if self._key_length != len(key):
             raise errors.BadIndexKey(key)

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2009-10-07 15:48:32 +0000
+++ bzrlib/tests/__init__.py	2009-10-08 04:35:01 +0000
@@ -3670,7 +3670,6 @@
         'bzrlib.tests.test__known_graph',
         'bzrlib.tests.test__rio',
         'bzrlib.tests.test__simple_set',
-        'bzrlib.tests.test__static_tuple',
         'bzrlib.tests.test__walkdirs_win32',
         'bzrlib.tests.test_ancestry',
         'bzrlib.tests.test_annotate',

=== modified file 'bzrlib/tests/test__simple_set.py'
--- bzrlib/tests/test__simple_set.py	2009-10-07 19:31:39 +0000
+++ bzrlib/tests/test__simple_set.py	2009-10-08 04:35:01 +0000
@@ -24,39 +24,32 @@
     tests,
     )
 
-from bzrlib.tests import (
-    test__static_tuple,
-    )
-try:
-    from bzrlib import _simple_set_pyx as _module
-except ImportError:
-    _module = None
-try:
-    from bzrlib._static_tuple_c import StaticTuple
-except ImportError:
-    from bzrlib._static_tuple_py import StaticTuple
+try:
+    from bzrlib import _simple_set_pyx
+except ImportError:
+    _simple_set_pyx = None
 
 
 # Even though this is an extension, we don't permute the tests for a python
 # version. As the plain python version is just a dict or set
 
-class _CompiledStaticTupleInterned(tests.Feature):
+class _CompiledSimpleSet(tests.Feature):
 
     def _probe(self):
-        if _module is None:
+        if _simple_set_pyx is None:
             return False
         return True
 
     def feature_name(self):
         return 'bzrlib._simple_set_pyx'
 
-CompiledStaticTupleInterned = _CompiledStaticTupleInterned()
-
-
-class TestStaticTupleInterned(tests.TestCase):
-
-    _test_needs_features = [CompiledStaticTupleInterned, 
-                            test__static_tuple.CompiledStaticTuple]
+CompiledSimpleSet = _CompiledSimpleSet()
+
+
+class TestSimpleSet(tests.TestCase):
+
+    _test_needs_features = [CompiledSimpleSet]
+    module = _simple_set_pyx
 
     def assertIn(self, obj, container):
         self.assertTrue(obj in container,
@@ -76,17 +69,15 @@
         assertRefcount actually creates a new pointer, as does calling
         sys.getrefcount. So pass the expected value *before* the call.
         """
-        # I don't understand why it is count+3 here, but it seems to be
-        # correct. If I check in the calling function, with:
-        # self.assertEqual(count+1, sys.getrefcount(obj))
-        # Then it works fine. Something about passing it to assertRefcount is
-        # actually double-incrementing (and decrementing) the refcount
-        self.assertEqual(count+3, sys.getrefcount(obj))
+        # I'm not sure why the offset is 3, but I've check that in the caller,
+        # an offset of 1 works, which is expected. Not sure why assertRefcount
+        # is incrementing/decrementing 2 times
+        self.assertEqual(count, sys.getrefcount(obj)-3)
 
     def test_initial(self):
-        obj = _module.SimpleSet()
+        obj = self.module.SimpleSet()
         self.assertEqual(0, len(obj))
-        st = StaticTuple('foo', 'bar')
+        st = ('foo', 'bar')
         self.assertFillState(0, 0, 0x3ff, obj)
 
     def test__lookup(self):
@@ -98,23 +89,23 @@
         #  ('a', 'a'), ('f', '4'), ('p', 'r'), ('q', '1'), ('F', 'T'),
         #  ('Q', 'Q'), ('V', 'd'), ('7', 'C')
         # all collide @ 643
-        obj = _module.SimpleSet()
-        offset, val = obj._test_lookup(StaticTuple('a', 'a'))
-        self.assertEqual(643, offset)
-        self.assertEqual('<null>', val)
-        offset, val = obj._test_lookup(StaticTuple('f', '4'))
-        self.assertEqual(643, offset)
-        self.assertEqual('<null>', val)
-        offset, val = obj._test_lookup(StaticTuple('p', 'r'))
+        obj = self.module.SimpleSet()
+        offset, val = obj._test_lookup(('a', 'a'))
+        self.assertEqual(643, offset)
+        self.assertEqual('<null>', val)
+        offset, val = obj._test_lookup(('f', '4'))
+        self.assertEqual(643, offset)
+        self.assertEqual('<null>', val)
+        offset, val = obj._test_lookup(('p', 'r'))
         self.assertEqual(643, offset)
         self.assertEqual('<null>', val)
 
     def test_get_set_del_with_collisions(self):
-        obj = _module.SimpleSet()
-        k1 = StaticTuple('a', 'a')
-        k2 = StaticTuple('f', '4') # collides
-        k3 = StaticTuple('p', 'r')
-        k4 = StaticTuple('q', '1')
+        obj = self.module.SimpleSet()
+        k1 = ('a', 'a')
+        k2 = ('f', '4') # collides
+        k3 = ('p', 'r')
+        k4 = ('q', '1')
         self.assertEqual((643, '<null>'), obj._test_lookup(k1))
         self.assertEqual((643, '<null>'), obj._test_lookup(k2))
         self.assertEqual((643, '<null>'), obj._test_lookup(k3))
@@ -160,9 +151,12 @@
         self.assertNotIn(k4, obj)
 
     def test_add(self):
-        obj = _module.SimpleSet()
+        obj = self.module.SimpleSet()
         self.assertFillState(0, 0, 0x3ff, obj)
-        k1 = StaticTuple('foo')
+        # We use this clumsy notation, because otherwise the refcounts are off.
+        # I'm guessing the python compiler sees it is a static tuple, and adds
+        # it to the function variables, or somesuch
+        k1 = tuple(['foo'])
         self.assertRefcount(1, k1)
         self.assertIs(k1, obj.add(k1))
         self.assertFillState(1, 1, 0x3ff, obj)
@@ -172,7 +166,7 @@
         self.assertIs(k1, ktest)
         del ktest
         self.assertRefcount(2, k1)
-        k2 = StaticTuple('foo')
+        k2 = tuple(['foo'])
         self.assertRefcount(1, k2)
         self.assertIsNot(k1, k2)
         # doesn't add anything, so the counters shouldn't be adjusted
@@ -188,7 +182,7 @@
         del obj[k1]
         self.assertFillState(0, 1, 0x3ff, obj)
         self.assertRefcount(1, k1)
-        k3 = StaticTuple('bar')
+        k3 = tuple(['bar'])
         self.assertRefcount(1, k3)
         self.assertIs(k3, obj.add(k3))
         self.assertFillState(1, 2, 0x3ff, obj)
@@ -200,10 +194,10 @@
         self.assertRefcount(2, k3)
 
     def test_discard(self):
-        obj = _module.SimpleSet()
-        k1 = StaticTuple('foo')
-        k2 = StaticTuple('foo')
-        k3 = StaticTuple('bar')
+        obj = self.module.SimpleSet()
+        k1 = tuple(['foo'])
+        k2 = tuple(['foo'])
+        k3 = tuple(['bar'])
         self.assertRefcount(1, k1)
         self.assertRefcount(1, k2)
         self.assertRefcount(1, k3)
@@ -217,10 +211,10 @@
         self.assertRefcount(1, k3)
 
     def test__delitem__(self):
-        obj = _module.SimpleSet()
-        k1 = StaticTuple('foo')
-        k2 = StaticTuple('foo')
-        k3 = StaticTuple('bar')
+        obj = self.module.SimpleSet()
+        k1 = tuple(['foo'])
+        k2 = tuple(['foo'])
+        k3 = tuple(['bar'])
         self.assertRefcount(1, k1)
         self.assertRefcount(1, k2)
         self.assertRefcount(1, k3)
@@ -234,10 +228,10 @@
         self.assertRefcount(1, k3)
 
     def test__resize(self):
-        obj = _module.SimpleSet()
-        k1 = StaticTuple('foo')
-        k2 = StaticTuple('bar')
-        k3 = StaticTuple('baz')
+        obj = self.module.SimpleSet()
+        k1 = ('foo',)
+        k2 = ('bar',)
+        k3 = ('baz',)
         obj.add(k1)
         obj.add(k2)
         obj.add(k3)
@@ -264,18 +258,18 @@
         self.assertEqual((591, '<null>'), obj._test_lookup(k2))
 
     def test_add_and_remove_lots_of_items(self):
-        obj = _module.SimpleSet()
+        obj = self.module.SimpleSet()
         chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz1234567890'
         for i in chars:
             for j in chars:
-                k = StaticTuple(i, j)
+                k = (i, j)
                 obj.add(k)
         num = len(chars)*len(chars)
         self.assertFillState(num, num, 0x1fff, obj)
         # Now delete all of the entries and it should shrink again
         for i in chars:
             for j in chars:
-                k = StaticTuple(i, j)
+                k = (i, j)
                 obj.discard(k)
         # It should be back to 1024 wide mask, though there may still be some
         # dummy values in there
@@ -284,10 +278,10 @@
         self.assertTrue(obj.fill < 1024 / 5)
 
     def test__iter__(self):
-        obj = _module.SimpleSet()
-        k1 = StaticTuple('1')
-        k2 = StaticTuple('1', '2')
-        k3 = StaticTuple('3', '4')
+        obj = self.module.SimpleSet()
+        k1 = ('1',)
+        k2 = ('1', '2')
+        k3 = ('3', '4')
         obj.add(k1)
         obj.add(k2)
         obj.add(k3)
@@ -297,7 +291,7 @@
         self.assertEqual(sorted([k1, k2, k3]), sorted(all))
         iterator = iter(obj)
         iterator.next()
-        obj.add(StaticTuple('foo'))
+        obj.add(('foo',))
         # Set changed size
         self.assertRaises(RuntimeError, iterator.next)
         # And even removing an item still causes it to fail

=== removed file 'bzrlib/tests/test__static_tuple.py'
--- bzrlib/tests/test__static_tuple.py	2009-10-07 19:34:22 +0000
+++ bzrlib/tests/test__static_tuple.py	1970-01-01 00:00:00 +0000
@@ -1,385 +0,0 @@
-# Copyright (C) 2009 Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
-"""Tests for the StaticTuple type."""
-
-import gc
-import sys
-
-from bzrlib import (
-    _static_tuple_py,
-    errors,
-    osutils,
-    tests,
-    )
-
-
-def load_tests(standard_tests, module, loader):
-    """Parameterize tests for all versions of groupcompress."""
-    scenarios = [
-        ('python', {'module': _static_tuple_py}),
-    ]
-    suite = loader.suiteClass()
-    if CompiledStaticTuple.available():
-        from bzrlib import _static_tuple_c
-        scenarios.append(('C', {'module': _static_tuple_c}))
-    else:
-        # the compiled module isn't available, so we add a failing test
-        class FailWithoutFeature(tests.TestCase):
-            def test_fail(self):
-                self.requireFeature(CompiledStaticTuple)
-        suite.addTest(loader.loadTestsFromTestCase(FailWithoutFeature))
-    result = tests.multiply_tests(standard_tests, scenarios, suite)
-    return result
-
-
-class _CompiledStaticTuple(tests.Feature):
-
-    def _probe(self):
-        try:
-            import bzrlib._static_tuple_c
-        except ImportError:
-            return False
-        return True
-
-    def feature_name(self):
-        return 'bzrlib._static_tuple_c'
-
-CompiledStaticTuple = _CompiledStaticTuple()
-
-
-class _Meliae(tests.Feature):
-
-    def _probe(self):
-        try:
-            from meliae import scanner
-        except ImportError:
-            return False
-        return True
-
-    def feature_name(self):
-        return "Meliae - python memory debugger"
-
-Meliae = _Meliae()
-
-
-class TestStaticTuple(tests.TestCase):
-
-    def assertRefcount(self, count, obj):
-        """Assert that the refcount for obj is what we expect.
-
-        Note that this automatically adjusts for the fact that calling
-        assertRefcount actually creates a new pointer, as does calling
-        sys.getrefcount. So pass the expected value *before* the call.
-        """
-        # I don't understand why it is getrefcount()-3 here, but it seems to be
-        # correct. If I check in the calling function, with:
-        # self.assertEqual(count, sys.getrefcount(obj)-1)
-        # Then it works fine. Something about passing it to assertRefcount is
-        # actually double-incrementing (and decrementing) the refcount
-        self.assertEqual(count, sys.getrefcount(obj)-3)
-
-    def test_create(self):
-        k = self.module.StaticTuple('foo')
-        k = self.module.StaticTuple('foo', 'bar')
-
-    def test_create_bad_args(self):
-        args_256 = ['a']*256
-        # too many args
-        self.assertRaises(ValueError, self.module.StaticTuple, *args_256)
-        args_300 = ['a']*300
-        self.assertRaises(ValueError, self.module.StaticTuple, *args_300)
-        # not a string
-        self.assertRaises(TypeError, self.module.StaticTuple, 10)
-        
-    def test_as_tuple(self):
-        k = self.module.StaticTuple('foo')
-        t = k.as_tuple()
-        self.assertEqual(('foo',), t)
-        k = self.module.StaticTuple('foo', 'bar')
-        t = k.as_tuple()
-        self.assertEqual(('foo', 'bar'), t)
-
-    def test_len(self):
-        k = self.module.StaticTuple()
-        self.assertEqual(0, len(k))
-        k = self.module.StaticTuple('foo')
-        self.assertEqual(1, len(k))
-        k = self.module.StaticTuple('foo', 'bar')
-        self.assertEqual(2, len(k))
-        k = self.module.StaticTuple('foo', 'bar', 'b', 'b', 'b', 'b', 'b')
-        self.assertEqual(7, len(k))
-        args = ['foo']*255
-        k = self.module.StaticTuple(*args)
-        self.assertEqual(255, len(k))
-
-    def test_hold_other_static_tuples(self):
-        k = self.module.StaticTuple('foo', 'bar')
-        k2 = self.module.StaticTuple(k, k)
-        self.assertEqual(2, len(k2))
-        self.assertIs(k, k2[0])
-        self.assertIs(k, k2[1])
-
-    def test_getitem(self):
-        k = self.module.StaticTuple('foo', 'bar', 'b', 'b', 'b', 'b', 'z')
-        self.assertEqual('foo', k[0])
-        self.assertEqual('foo', k[0])
-        self.assertEqual('foo', k[0])
-        self.assertEqual('z', k[6])
-        self.assertEqual('z', k[-1])
-
-    def test_refcount(self):
-        f = 'fo' + 'oo'
-        num_refs = sys.getrefcount(f) - 1 #sys.getrefcount() adds one
-        k = self.module.StaticTuple(f)
-        self.assertRefcount(num_refs + 1, f)
-        b = k[0]
-        self.assertRefcount(num_refs + 2, f)
-        b = k[0]
-        self.assertRefcount(num_refs + 2, f)
-        c = k[0]
-        self.assertRefcount(num_refs + 3, f)
-        del b, c
-        self.assertRefcount(num_refs + 1, f)
-        del k
-        self.assertRefcount(num_refs, f)
-
-    def test__repr__(self):
-        k = self.module.StaticTuple('foo', 'bar', 'baz', 'bing')
-        self.assertEqual("StaticTuple('foo', 'bar', 'baz', 'bing')", repr(k))
-
-    def assertCompareEqual(self, k1, k2):
-        self.assertTrue(k1 == k2)
-        self.assertTrue(k1 <= k2)
-        self.assertTrue(k1 >= k2)
-        self.assertFalse(k1 != k2)
-        self.assertFalse(k1 < k2)
-        self.assertFalse(k1 > k2)
-
-    def test_compare_same_obj(self):
-        k1 = self.module.StaticTuple('foo', 'bar')
-        self.assertCompareEqual(k1, k1)
-        k2 = self.module.StaticTuple(k1, k1)
-        self.assertCompareEqual(k2, k2)
-
-    def test_compare_equivalent_obj(self):
-        k1 = self.module.StaticTuple('foo', 'bar')
-        k2 = self.module.StaticTuple('foo', 'bar')
-        self.assertCompareEqual(k1, k2)
-        k3 = self.module.StaticTuple(k1, k2)
-        k4 = self.module.StaticTuple(k2, k1)
-        self.assertCompareEqual(k1, k2)
-
-    def test_compare_similar_obj(self):
-        k1 = self.module.StaticTuple('foo' + ' bar', 'bar' + ' baz')
-        k2 = self.module.StaticTuple('fo' + 'o bar', 'ba' + 'r baz')
-        self.assertCompareEqual(k1, k2)
-        k3 = self.module.StaticTuple('foo ' + 'bar', 'bar ' + 'baz')
-        k4 = self.module.StaticTuple('f' + 'oo bar', 'b' + 'ar baz')
-        k5 = self.module.StaticTuple(k1, k2)
-        k6 = self.module.StaticTuple(k3, k4)
-        self.assertCompareEqual(k5, k6)
-
-    def assertCompareDifferent(self, k_small, k_big):
-        self.assertFalse(k_small == k_big)
-        self.assertFalse(k_small >= k_big)
-        self.assertFalse(k_small > k_big)
-        self.assertTrue(k_small != k_big)
-        self.assertTrue(k_small <= k_big)
-        self.assertTrue(k_small < k_big)
-
-    def test_compare_vs_none(self):
-        k1 = self.module.StaticTuple('baz', 'bing')
-        self.assertCompareDifferent(None, k1)
-        self.assertCompareDifferent(10, k1)
-        # Comparison with a string is poorly-defined, I seem to get failures
-        # regardless of which one comes first...
-        # self.assertCompareDifferent('baz', k1)
-
-    def test_compare_all_different_same_width(self):
-        k1 = self.module.StaticTuple('baz', 'bing')
-        k2 = self.module.StaticTuple('foo', 'bar')
-        self.assertCompareDifferent(k1, k2)
-        k3 = self.module.StaticTuple(k1, k2)
-        k4 = self.module.StaticTuple(k2, k1)
-        self.assertCompareDifferent(k3, k4)
-
-    def test_compare_some_different(self):
-        k1 = self.module.StaticTuple('foo', 'bar')
-        k2 = self.module.StaticTuple('foo', 'zzz')
-        self.assertCompareDifferent(k1, k2)
-        k3 = self.module.StaticTuple(k1, k1)
-        k4 = self.module.StaticTuple(k1, k2)
-        self.assertCompareDifferent(k3, k4)
-
-    def test_compare_diff_width(self):
-        k1 = self.module.StaticTuple('foo')
-        k2 = self.module.StaticTuple('foo', 'bar')
-        self.assertCompareDifferent(k1, k2)
-        k3 = self.module.StaticTuple(k1)
-        k4 = self.module.StaticTuple(k1, k2)
-        self.assertCompareDifferent(k3, k4)
-
-    def test_compare_to_tuples(self):
-        k1 = self.module.StaticTuple('foo')
-        self.assertCompareEqual(k1, ('foo',))
-        self.assertCompareEqual(('foo',), k1)
-        self.assertCompareDifferent(k1, ('foo', 'bar'))
-        self.assertCompareDifferent(k1, ('foo', 10))
-
-        k2 = self.module.StaticTuple('foo', 'bar')
-        self.assertCompareEqual(k2, ('foo', 'bar'))
-        self.assertCompareEqual(('foo', 'bar'), k2)
-        self.assertCompareDifferent(k2, ('foo', 'zzz'))
-        self.assertCompareDifferent(('foo',), k2)
-        self.assertCompareDifferent(('foo', 'aaa'), k2)
-        self.assertCompareDifferent(('baz', 'bing'), k2)
-        self.assertCompareDifferent(('foo', 10), k2)
-
-        k3 = self.module.StaticTuple(k1, k2)
-        self.assertCompareEqual(k3, (('foo',), ('foo', 'bar')))
-        self.assertCompareEqual((('foo',), ('foo', 'bar')), k3)
-        self.assertCompareEqual(k3, (k1, ('foo', 'bar')))
-        self.assertCompareEqual((k1, ('foo', 'bar')), k3)
-
-    def test_hash(self):
-        k = self.module.StaticTuple('foo')
-        self.assertEqual(hash(k), hash(('foo',)))
-        k = self.module.StaticTuple('foo', 'bar', 'baz', 'bing')
-        as_tuple = ('foo', 'bar', 'baz', 'bing')
-        self.assertEqual(hash(k), hash(as_tuple))
-        x = {k: 'foo'}
-        # Because k == , it replaces the slot, rather than having both
-        # present in the dict.
-        self.assertEqual('foo', x[as_tuple])
-        x[as_tuple] = 'bar'
-        self.assertEqual({as_tuple: 'bar'}, x)
-
-        k2 = self.module.StaticTuple(k)
-        as_tuple2 = (('foo', 'bar', 'baz', 'bing'),)
-        self.assertEqual(hash(k2), hash(as_tuple2))
-
-    def test_slice(self):
-        k = self.module.StaticTuple('foo', 'bar', 'baz', 'bing')
-        self.assertEqual(('foo', 'bar'), k[:2])
-        self.assertEqual(('baz',), k[2:-1])
-
-    def test_referents(self):
-        # We implement tp_traverse so that things like 'meliae' can measure the
-        # amount of referenced memory. Unfortunately gc.get_referents() first
-        # checks the IS_GC flag before it traverses anything. So there isn't a
-        # way to expose it that I can see.
-        self.requireFeature(Meliae)
-        from meliae import scanner
-        strs = ['foo', 'bar', 'baz', 'bing']
-        k = self.module.StaticTuple(*strs)
-        if self.module is _static_tuple_py:
-            refs = strs + [self.module.StaticTuple]
-        else:
-            refs = strs
-        self.assertEqual(sorted(refs), sorted(scanner.get_referents(k)))
-
-    def test_nested_referents(self):
-        self.requireFeature(Meliae)
-        from meliae import scanner
-        strs = ['foo', 'bar', 'baz', 'bing']
-        k1 = self.module.StaticTuple(*strs[:2])
-        k2 = self.module.StaticTuple(*strs[2:])
-        k3 = self.module.StaticTuple(k1, k2)
-        refs = [k1, k2]
-        if self.module is _static_tuple_py:
-            refs.append(self.module.StaticTuple)
-        self.assertEqual(sorted(refs),
-                         sorted(scanner.get_referents(k3)))
-
-    def test_empty_is_singleton(self):
-        key = self.module.StaticTuple()
-        self.assertIs(key, self.module._empty_tuple)
-
-    def test_intern(self):
-        unique_str1 = 'unique str ' + osutils.rand_chars(20)
-        unique_str2 = 'unique str ' + osutils.rand_chars(20)
-        key = self.module.StaticTuple(unique_str1, unique_str2)
-        self.assertFalse(key in self.module._interned_tuples)
-        key2 = self.module.StaticTuple(unique_str1, unique_str2)
-        self.assertEqual(key, key2)
-        self.assertIsNot(key, key2)
-        key3 = key.intern()
-        self.assertIs(key, key3)
-        self.assertTrue(key in self.module._interned_tuples)
-        self.assertEqual(key, self.module._interned_tuples[key])
-        key2 = key2.intern()
-        self.assertIs(key, key2)
-
-    def test__c_intern_handles_refcount(self):
-        if self.module is _static_tuple_py:
-            return # Not applicable
-        unique_str1 = 'unique str ' + osutils.rand_chars(20)
-        unique_str2 = 'unique str ' + osutils.rand_chars(20)
-        key = self.module.StaticTuple(unique_str1, unique_str2)
-        self.assertRefcount(1, key)
-        self.assertFalse(key in self.module._interned_tuples)
-        self.assertFalse(key._is_interned())
-        key2 = self.module.StaticTuple(unique_str1, unique_str2)
-        self.assertRefcount(1, key)
-        self.assertRefcount(1, key2)
-        self.assertEqual(key, key2)
-        self.assertIsNot(key, key2)
-
-        key3 = key.intern()
-        self.assertIs(key, key3)
-        self.assertTrue(key in self.module._interned_tuples)
-        self.assertEqual(key, self.module._interned_tuples[key])
-        # key and key3, but we 'hide' the one in _interned_tuples
-        self.assertRefcount(2, key)
-        del key3
-        self.assertRefcount(1, key)
-        self.assertTrue(key._is_interned())
-        self.assertRefcount(1, key2)
-        key3 = key2.intern()
-        # key3 now points to key as well, and *not* to key2
-        self.assertRefcount(2, key)
-        self.assertRefcount(1, key2)
-        self.assertIs(key, key3)
-        self.assertIsNot(key3, key2)
-        del key2
-        del key3
-        self.assertRefcount(1, key)
-
-    def test__c_keys_are_not_immortal(self):
-        if self.module is _static_tuple_py:
-            return # Not applicable
-        unique_str1 = 'unique str ' + osutils.rand_chars(20)
-        unique_str2 = 'unique str ' + osutils.rand_chars(20)
-        key = self.module.StaticTuple(unique_str1, unique_str2)
-        self.assertFalse(key in self.module._interned_tuples)
-        self.assertRefcount(1, key)
-        key = key.intern()
-        self.assertRefcount(1, key)
-        self.assertTrue(key in self.module._interned_tuples)
-        self.assertTrue(key._is_interned())
-        del key
-        # Create a new entry, which would point to the same location
-        key = self.module.StaticTuple(unique_str1, unique_str2)
-        self.assertRefcount(1, key)
-        # This old entry in _interned_tuples should be gone
-        self.assertFalse(key in self.module._interned_tuples)
-        self.assertFalse(key._is_interned())
-
-    def test__c_has_C_API(self):
-        if self.module is _static_tuple_py:
-            return
-        self.assertIsNot(None, self.module._C_API)

=== modified file 'bzrlib/tests/test_chk_map.py'
--- bzrlib/tests/test_chk_map.py	2009-09-30 21:53:59 +0000
+++ bzrlib/tests/test_chk_map.py	2009-10-08 04:35:01 +0000
@@ -831,13 +831,13 @@
         # 'ab' and 'ac' nodes
         chkmap.map(('aad',), 'v')
         self.assertIsInstance(chkmap._root_node._items['aa'], InternalNode)
-        self.assertIsInstance(chkmap._root_node._items['ab'], (tuple, chk_map._key_type))
-        self.assertIsInstance(chkmap._root_node._items['ac'], (tuple, chk_map._key_type))
+        self.assertIsInstance(chkmap._root_node._items['ab'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['ac'], tuple)
         # Unmapping 'acd' can notice that 'aa' is an InternalNode and not have
         # to map in 'ab'
         chkmap.unmap(('acd',))
         self.assertIsInstance(chkmap._root_node._items['aa'], InternalNode)
-        self.assertIsInstance(chkmap._root_node._items['ab'], (tuple, chk_map._key_type))
+        self.assertIsInstance(chkmap._root_node._items['ab'], tuple)
 
     def test_unmap_without_fitting_doesnt_page_in(self):
         store = self.get_chk_bytes()
@@ -860,9 +860,8 @@
         chkmap.map(('aaf',), 'v')
         # At this point, the previous nodes should not be paged in, but the
         # newly added nodes would be
-        self.assertIsInstance(chkmap._root_node._items['aaa'], (tuple,
-        chk_map._key_type))
-        self.assertIsInstance(chkmap._root_node._items['aab'], (tuple, chk_map._key_type))
+        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
         self.assertIsInstance(chkmap._root_node._items['aac'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aad'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aae'], LeafNode)
@@ -870,8 +869,8 @@
         # Now unmapping one of the new nodes will use only the already-paged-in
         # nodes to determine that we don't need to do more.
         chkmap.unmap(('aaf',))
-        self.assertIsInstance(chkmap._root_node._items['aaa'], (tuple, chk_map._key_type))
-        self.assertIsInstance(chkmap._root_node._items['aab'], (tuple, chk_map._key_type))
+        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
         self.assertIsInstance(chkmap._root_node._items['aac'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aad'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aae'], LeafNode)
@@ -898,12 +897,9 @@
         chkmap.map(('aad',), 'v')
         # At this point, the previous nodes should not be paged in, but the
         # newly added node would be
-        self.assertIsInstance(chkmap._root_node._items['aaa'], (tuple,
-        chk_map._key_type))
-        self.assertIsInstance(chkmap._root_node._items['aab'], (tuple,
-        chk_map._key_type))
-        self.assertIsInstance(chkmap._root_node._items['aac'], (tuple,
-        chk_map._key_type))
+        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aac'], tuple)
         self.assertIsInstance(chkmap._root_node._items['aad'], LeafNode)
         # Unmapping the new node will check the existing nodes to see if they
         # would fit.
@@ -941,12 +937,9 @@
         chkmap.map(('aad',), 'v')
         # At this point, the previous nodes should not be paged in, but the
         # newly added node would be
-        self.assertIsInstance(chkmap._root_node._items['aaa'], (tuple,
-        chk_map._key_type))
-        self.assertIsInstance(chkmap._root_node._items['aab'], (tuple,
-        chk_map._key_type))
-        self.assertIsInstance(chkmap._root_node._items['aac'], (tuple,
-        chk_map._key_type))
+        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aac'], tuple)
         self.assertIsInstance(chkmap._root_node._items['aad'], LeafNode)
         # Now clear the page cache, and only include 2 of the children in the
         # cache
@@ -961,8 +954,7 @@
         # Unmapping the new node will check the nodes from the page cache
         # first, and not have to read in 'aaa'
         chkmap.unmap(('aad',))
-        self.assertIsInstance(chkmap._root_node._items['aaa'], (tuple,
-        chk_map._key_type))
+        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
         self.assertIsInstance(chkmap._root_node._items['aab'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aac'], LeafNode)
 
@@ -982,12 +974,9 @@
         chkmap.map(('aaf',), 'val')
         # At this point, the previous nodes should not be paged in, but the
         # newly added node would be
-        self.assertIsInstance(chkmap._root_node._items['aaa'], (tuple,
-        chk_map._key_type))
-        self.assertIsInstance(chkmap._root_node._items['aab'], (tuple,
-        chk_map._key_type))
-        self.assertIsInstance(chkmap._root_node._items['aac'], (tuple,
-        chk_map._key_type))
+        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aac'], tuple)
         self.assertIsInstance(chkmap._root_node._items['aad'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aae'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aaf'], LeafNode)
@@ -995,12 +984,9 @@
         # Unmapping a new node will see the other nodes that are already in
         # memory, and not need to page in anything else
         chkmap.unmap(('aad',))
-        self.assertIsInstance(chkmap._root_node._items['aaa'], (tuple,
-        chk_map._key_type))
-        self.assertIsInstance(chkmap._root_node._items['aab'], (tuple,
-        chk_map._key_type))
-        self.assertIsInstance(chkmap._root_node._items['aac'], (tuple,
-        chk_map._key_type))
+        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aac'], tuple)
         self.assertIsInstance(chkmap._root_node._items['aae'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aaf'], LeafNode)
 
@@ -1045,8 +1031,8 @@
             {('a',): 'content here', ('b',): 'more content'},
             chk_bytes=basis._store, maximum_size=10)
         list(target.iter_changes(basis))
-        self.assertIsInstance(target._root_node, (tuple, chk_map._key_type))
-        self.assertIsInstance(basis._root_node, (tuple, chk_map._key_type))
+        self.assertIsInstance(target._root_node, tuple)
+        self.assertIsInstance(basis._root_node, tuple)
 
     def test_iter_changes_ab_ab_changed_values_shown(self):
         basis = self._get_map({('a',): 'content here', ('b',): 'more content'},
@@ -1946,7 +1932,7 @@
         # Ensure test validity: nothing paged in below the root.
         self.assertEqual(2,
             len([value for value in node._items.values()
-                if type(value) in (tuple, chk_map._key_type)]))
+                if type(value) == tuple]))
         # now, mapping to k3 should add a k3 leaf
         prefix, nodes = node.map(None, ('k3',), 'quux')
         self.assertEqual("k", prefix)
@@ -1985,7 +1971,7 @@
         # Ensure test validity: nothing paged in below the root.
         self.assertEqual(2,
             len([value for value in node._items.values()
-                if type(value) in (tuple, chk_map._key_type)]))
+                if type(value) == tuple]))
         # now, mapping to k23 causes k22 ('k2' in node) to split into k22 and
         # k23, which for simplicity in the current implementation generates
         # a new internal node between node, and k22/k23.

=== modified file 'setup.py'
--- setup.py	2009-10-07 15:48:32 +0000
+++ setup.py	2009-10-08 04:35:01 +0000
@@ -265,6 +265,7 @@
 
 add_pyrex_extension('bzrlib._annotator_pyx')
 add_pyrex_extension('bzrlib._bencode_pyx')
+add_pyrex_extension('bzrlib._btree_serializer_pyx')
 add_pyrex_extension('bzrlib._chunks_to_lines_pyx')
 add_pyrex_extension('bzrlib._groupcompress_pyx',
                     extra_source=['bzrlib/diff-delta.c'])
@@ -295,9 +296,6 @@
 ext_modules.append(Extension('bzrlib._patiencediff_c',
                              ['bzrlib/_patiencediff_c.c']))
 add_pyrex_extension('bzrlib._simple_set_pyx')
-ext_modules.append(Extension('bzrlib._static_tuple_c',
-                             ['bzrlib/_static_tuple_c.c']))
-add_pyrex_extension('bzrlib._btree_serializer_pyx')
 
 
 if unavailable_files:

